Module protocol

Module protocol 

Structs

ActionEntry
Single entry in the action history for agent reasoning.
EntityQuery
Filter for finding entities by semantic properties.
EntitySummary
Summary of a single entity for agent consumption.

Enums

DaemonMessage
Messages sent over Unix Domain Socket between daemon and client.
ErrorCode
Structured error codes for machine-readable error handling.