Structs
- Action
Entry - Single entry in the action history for agent reasoning.
- Entity
Query - Filter for finding entities by semantic properties.
- Entity
Summary - Summary of a single entity for agent consumption.
Enums
- Daemon
Message - Messages sent over Unix Domain Socket between daemon and client.
- Error
Code - Structured error codes for machine-readable error handling.